@@ -9,8 +9,11 @@ from PyFin.tests.DateUtilities.testCalendar import TestCalendar
 from PyFin.tests.DateUtilities.testDate import TestDate
 from PyFin.tests.DateUtilities.testPeriod import TestPeriod
 from PyFin.tests.DateUtilities.testSchedule import TestSchedule
+from PyFin.tests.DateUtilities.testDayCounter import TestDayCounter
+
 
 __all__ = ["TestCalendar",
            "TestDate",
            "TestPeriod",
-           "TestSchedule"]
+           "TestSchedule",
+           "TestDayCounter"]
