@@ -11,7 +11,6 @@ import copy
 import tempfile
 import pickle
 import os
-from PyFin.Math.MathConstants import MathConstants
 from PyFin.Math.Distributions import InverseCumulativeNormal
 from PyFin.Math.Distributions import NormalDistribution
 from PyFin.Math.Distributions import CumulativeNormalDistribution
@@ -21,13 +20,13 @@ sigma = 2.0
 
 
 def gaussian(x):
-    normFact = sigma * math.sqrt(2.0 * MathConstants.M_PI)
+    normFact = sigma * math.sqrt(2.0 * math.pi)
     dx = x - average
     return math.exp(-dx * dx / (2.0 * sigma * sigma)) / normFact
 
 
 def gaussianDerivative(x):
-    normFact = sigma * sigma * sigma * math.sqrt(2.0 * MathConstants.M_PI)
+    normFact = sigma * sigma * sigma * math.sqrt(2.0 * math.pi)
     dx = x - average
     return -dx * math.exp(-dx * dx / (2.0 * sigma * sigma)) / normFact
 
